emperor.Emperor
===============

.. currentmodule:: emperor

.. autoclass:: Emperor

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Emperor.__format__
         Emperor.__init__
         Emperor.__new__
         Emperor.__reduce__
         Emperor.__reduce_ex__
         Emperor.__sizeof__
         Emperor.__str__
         Emperor.__subclasshook__
         Emperor._repr_html_
         Emperor.copy_support_files
         Emperor.make_emperor



   

